#ifndef NT2_INCLUDE_FUNCTIONS_GENMASK_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GENMASK_HPP_INCLUDED

#include <nt2/bitwise/include/functions/genmask.hpp>

#endif
